==> nextcloud-29.0.9.tgz: nextcloud/apps/user_status/l10n/ca.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Estats recents",
    "No recent status changes" : "No hi ha cap canvi d'estat recent",
    "In a meeting" : "En una reunió",
    "Commuting" : "En desplaçament",
    "Out sick" : "No disponible per malaltia",
    "Vacationing" : "De vacances",
    "Out of office" : "Fora de l'oficina",
    "Working remotely" : "Treballant en remot",
    "In a call" : "En una trucada",
    "User status" : "Estat de l'usuari",
    "Clear status after" : "Esborra l'estat després de",
    "Emoji for your status message" : "Emoji per al missatge d'estat",
    "What is your status?" : "Quin és el vostre estat?",
    "Predefined statuses" : "Estats predefinits",
    "Previously set" : "Definits anteriorment",
    "Reset status" : "Reinicialitza l'estat",
    "Set status" : "Indica l'estat",
    "Online status" : "Estat en línia",
    "Status message" : "Missatge d'estat",
    "Your status was set automatically" : "S'ha indicat l'estat automàticament",
    "Clear status message" : "Esborra el missatge d'estat",
    "Set status message" : "Indica el missatge d'estat",
    "Reset status to \"{icon} {message}\"" : "Reinicialitza l'estat a «{icon} {message}»",
    "Reset status to \"{message}\"" : "Reinicialitza l'estat a «{message}»",
    "Reset status to \"{icon}\"" : "Reinicialitza l'estat a «{icon}»",
    "There was an error saving the status" : "S'ha produït un error en desar l'estat",
    "There was an error clearing the status" : "S'ha produït un error en esborrar l'estat",
    "There was an error reverting the status" : "S'ha produït un error en recuperar l'estat anterior",
    "Don't clear" : "No l'esborris",
    "Today" : "Avui",
    "This week" : "Aquesta setmana",
    "Online" : "En línia",
    "Away" : "Absent",
    "Do not disturb" : "No molesteu",
    "Invisible" : "Invisible",
    "Offline" : "Fora de línia",
    "There was an error saving the new status" : "S'ha produït un error en desar l'estat nou",
    "30 minutes" : "30 minuts",
    "1 hour" : "1 hora",
    "4 hours" : "4 hores",
    "Mute all notifications" : "Silencieu totes les notificacions",
    "Appear offline" : "Apareixeu fora de línia"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.12.tgz: nextcloud/apps/user_status/l10n/ca.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Estats recents",
    "No recent status changes" : "No hi ha cap canvi d'estat recent",
    "In a meeting" : "En una reunió",
    "Commuting" : "En desplaçament",
    "Out sick" : "No disponible per malaltia",
    "Vacationing" : "De vacances",
    "Out of office" : "Fora de l'oficina",
    "Working remotely" : "Treballant en remot",
    "In a call" : "En una trucada",
    "User status" : "Estat de l'usuari",
    "Clear status after" : "Esborra l'estat després de",
    "Emoji for your status message" : "Emoji per al missatge d'estat",
    "What is your status?" : "Quin és el vostre estat?",
    "Predefined statuses" : "Estats predefinits",
    "Previously set" : "Definits anteriorment",
    "Reset status" : "Reinicialitza l'estat",
    "Reset status to \"{icon} {message}\"" : "Reinicialitza l'estat a «{icon} {message}»",
    "Reset status to \"{message}\"" : "Reinicialitza l'estat a «{message}»",
    "Reset status to \"{icon}\"" : "Reinicialitza l'estat a «{icon}»",
    "There was an error saving the status" : "S'ha produït un error en desar l'estat",
    "There was an error clearing the status" : "S'ha produït un error en esborrar l'estat",
    "There was an error reverting the status" : "S'ha produït un error en recuperar l'estat anterior",
    "Set status" : "Indica l'estat",
    "Online status" : "Estat en línia",
    "Status message" : "Missatge d'estat",
    "Set absence period" : "Establir període d'absència",
    "Set absence period and replacement" : "Establir període d'absència i substitució",
    "Your status was set automatically" : "S'ha indicat l'estat automàticament",
    "Clear status message" : "Esborra el missatge d'estat",
    "Set status message" : "Indica el missatge d'estat",
    "Don't clear" : "No l'esborris",
    "Today" : "Avui",
    "This week" : "Aquesta setmana",
    "Online" : "En línia",
    "Away" : "Absent",
    "Do not disturb" : "No molesteu",
    "Invisible" : "Invisible",
    "Offline" : "Fora de línia",
    "There was an error saving the new status" : "S'ha produït un error en desar l'estat nou",
    "30 minutes" : "30 minuts",
    "1 hour" : "1 hora",
    "4 hours" : "4 hores",
    "Mute all notifications" : "Silencieu totes les notificacions",
    "Appear offline" : "Apareixeu fora de línia"
},
"nplurals=2; plural=(n != 1);");
